# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto
import sys

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

from examples.event_chain.protos import enum_pb2 as enum__pb2
from examples.event_chain.protos import state_pb2 as state__pb2
from examples.event_chain.protos import trace_type_pb2 as trace__type__pb2
from examples.event_chain.protos import tx_pb2 as tx__pb2
from examples.event_chain.protos import type_pb2 as type__pb2
from examples.event_chain.protos import vendor_pb2 as vendor__pb2
_b = sys.version_info[0] < 3 and (
    lambda x: x
) or (lambda x: x.encode('latin1'))
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='rpc.proto',
    package='forge_abi',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b('\n\trpc.proto\x12\tforge_abi\x1a\x19google/protobuf/any.proto\x1a\x0cvendor.proto\x1a\nenum.proto\x1a\ntype.proto\x1a\x0bstate.proto\x1a\x08tx.proto\x1a\x10trace_type.proto\"\x87\x01\n\x0fRequestCreateTx\x12!\n\x03itx\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\r\n\x05nonce\x18\x03 \x01(\x04\x12%\n\x06wallet\x18\x04 \x01(\x0b\x32\x15.forge_abi.WalletInfo\x12\r\n\x05token\x18\x05 \x01(\t\"[\n\x10ResponseCreateTx\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\"\n\x02tx\x18\x02 \x01(\x0b\x32\x16.forge_abi.Transaction\"k\n\x0fRequestMultisig\x12\"\n\x02tx\x18\x01 \x01(\x0b\x32\x16.forge_abi.Transaction\x12%\n\x06wallet\x18\x02 \x01(\x0b\x32\x15.forge_abi.WalletInfo\x12\r\n\x05token\x18\x03 \x01(\t\"[\n\x10ResponseMultisig\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\"\n\x02tx\x18\x02 \x01(\x0b\x32\x16.forge_abi.Transaction\"y\n\rRequestSendTx\x12\"\n\x02tx\x18\x01 \x01(\x0b\x32\x16.forge_abi.Transaction\x12%\n\x06wallet\x18\x02 \x01(\x0b\x32\x15.forge_abi.WalletInfo\x12\r\n\x05token\x18\x03 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x04 \x01(\x08\"C\n\x0eResponseSendTx\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x0c\n\x04hash\x18\x02 \x01(\t\"\x1c\n\x0cRequestGetTx\x12\x0c\n\x04hash\x18\x01 \x01(\t\"^\n\rResponseGetTx\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12(\n\x04info\x18\x02 \x01(\x0b\x32\x1a.forge_abi.TransactionInfo\"!\n\x0fRequestGetBlock\x12\x0e\n\x06height\x18\x01 \x01(\x04\"\\\n\x10ResponseGetBlock\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12#\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x14.forge_abi.BlockInfo\"x\n\x10RequestGetBlocks\x12$\n\x06paging\x18\x01 \x01(\x0b\x32\x14.forge_abi.PageInput\x12\x12\n\nmin_height\x18\x02 \x01(\x04\x12\x12\n\nmax_height\x18\x03 \x01(\x04\x12\x16\n\x0e\x65mpty_excluded\x18\x04 \x01(\x08\"\x81\x01\n\x11ResponseGetBlocks\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12!\n\x04page\x18\x02 \x01(\x0b\x32\x13.forge_abi.PageInfo\x12$\n\x06\x62locks\x18\x03 \x03(\x0b\x32\x14.forge_abi.BlockInfo\"_\n\x13RequestCreateWallet\x12\x12\n\npassphrase\x18\x01 \x01(\t\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x15.forge_abi.WalletType\x12\x0f\n\x07moniker\x18\x03 \x01(\t\"q\n\x14ResponseCreateWallet\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\r\n\x05token\x18\x02 \x01(\t\x12%\n\x06wallet\x18\x03 \x01(\x0b\x32\x15.forge_abi.WalletInfo\"8\n\x11RequestLoadWallet\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x12\n\npassphrase\x18\x02 \x01(\t\"o\n\x12ResponseLoadWallet\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\r\n\x05token\x18\x02 \x01(\t\x12%\n\x06wallet\x18\x03 \x01(\x0b\x32\x15.forge_abi.WalletInfo\"n\n\x14RequestRecoverWallet\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12#\n\x04type\x18\x02 \x01(\x0b\x32\x15.forge_abi.WalletType\x12\x12\n\npassphrase\x18\x03 \x01(\t\x12\x0f\n\x07moniker\x18\x04 \x01(\t\"r\n\x15ResponseRecoverWallet\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\r\n\x05token\x18\x02 \x01(\t\x12%\n\x06wallet\x18\x03 \x01(\x0b\x32\x15.forge_abi.WalletInfo\"\x13\n\x11RequestListWallet\"J\n\x12ResponseListWallet\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"&\n\x13RequestRemoveWallet\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\";\n\x14ResponseRemoveWallet\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\"\'\n\x12RequestDeclareNode\x12\x11\n\tvalidator\x18\x01 \x01(\x08\"a\n\x13ResponseDeclareNode\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12%\n\x06wallet\x18\x03 \x01(\x0b\x32\x15.forge_abi.WalletInfo\"I\n\x16RequestGetAccountState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x10\n\x08\x61pp_hash\x18\x03 \x01(\t\"f\n\x17ResponseGetAccountState\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12&\n\x05state\x18\x02 \x01(\x0b\x32\x17.forge_abi.AccountState\"G\n\x14RequestGetAssetState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x10\n\x08\x61pp_hash\x18\x03 \x01(\t\"b\n\x15ResponseGetAssetState\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12$\n\x05state\x18\x02 \x01(\x0b\x32\x15.forge_abi.AssetState\"G\n\x14RequestGetStakeState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x10\n\x08\x61pp_hash\x18\x03 \x01(\t\"b\n\x15ResponseGetStakeState\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12$\n\x05state\x18\x02 \x01(\x0b\x32\x15.forge_abi.StakeState\"6\n\x14RequestGetForgeState\x12\x0c\n\x04keys\x18\x01 \x03(\t\x12\x10\n\x08\x61pp_hash\x18\x02 \x01(\t\"b\n\x15ResponseGetForgeState\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12$\n\x05state\x18\x02 \x01(\x0b\x32\x15.forge_abi.ForgeState\"!\n\x10RequestStoreFile\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"F\n\x11ResponseStoreFile\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x0c\n\x04hash\x18\x02 \x01(\t\"\x1f\n\x0fRequestLoadFile\x12\x0c\n\x04hash\x18\x01 \x01(\t\"F\n\x10ResponseLoadFile\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\"\x1e\n\x0eRequestPinFile\x12\x0c\n\x04hash\x18\x01 \x01(\t\"6\n\x0fResponsePinFile\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\"\x15\n\x13RequestGetChainInfo\"_\n\x14ResponseGetChainInfo\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\"\n\x04info\x18\x02 \x01(\x0b\x32\x14.forge_abi.ChainInfo\"+\n\rRequestSearch\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"^\n\x0eResponseSearch\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\'\n\x03txs\x18\x02 \x03(\x0b\x32\x1a.forge_abi.TransactionInfo\")\n\x18RequestGetUnconfirmedTxs\x12\r\n\x05limit\x18\x01 \x01(\r\"t\n\x19ResponseGetUnconfirmedTxs\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x32\n\x0funconfirmed_txs\x18\x02 \x01(\x0b\x32\x19.forge_abi.UnconfirmedTxs\"\x13\n\x11RequestGetNetInfo\"_\n\x12ResponseGetNetInfo\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12$\n\x08net_info\x18\x02 \x01(\x0b\x32\x12.forge_abi.NetInfo\"\x1a\n\x18RequestGetValidatorsInfo\"t\n\x19ResponseGetValidatorsInfo\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x32\n\x0fvalidators_info\x18\x02 \x01(\x0b\x32\x19.forge_abi.ValidatorsInfo\"F\n\x10RequestSubscribe\x12\"\n\x04type\x18\x01 \x01(\x0e\x32\x14.forge_abi.TopicType\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\"\xa6\x07\n\x11ResponseSubscribe\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x0f\n\x05topic\x18\x02 \x01(\tH\x00\x12*\n\x08transfer\x18\x03 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12\x31\n\x0f\x61\x63\x63ount_migrate\x18\x04 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12)\n\x07\x63onfirm\x18\x05 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12.\n\x0c\x63reate_asset\x18\x06 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12*\n\x08\x65xchange\x18\x07 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12(\n\x06revoke\x18\x08 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12\x35\n\x0b\x62\x65gin_block\x18\x10 \x01(\x0b\x32\x1e.abci_vendor.RequestBeginBlockH\x00\x12\x31\n\tend_block\x18\x11 \x01(\x0b\x32\x1c.abci_vendor.RequestEndBlockH\x00\x12)\n\x07\x64\x65\x63lare\x18\x13 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12.\n\x0cupdate_asset\x18\x14 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12\x33\n\x11\x63onsensus_upgrade\x18\x15 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12.\n\x0c\x64\x65\x63lare_file\x18\x16 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12-\n\x0bsys_upgrade\x18\x17 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12\'\n\x05stake\x18\x18 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12\x30\n\raccount_state\x18\x81\x01 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12.\n\x0b\x61sset_state\x18\x82\x01 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12.\n\x0b\x66orge_state\x18\x83\x01 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x12.\n\x0bstake_state\x18\x84\x01 \x01(\x0b\x32\x16.forge_abi.TransactionH\x00\x42\x07\n\x05value\"#\n\x12RequestUnsubscribe\x12\r\n\x05topic\x18\x01 \x01(\t\":\n\x13ResponseUnsubscribe\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\"\x12\n\x10RequestGetConfig\"H\n\x11ResponseGetConfig\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"-\n\x05\x42yDay\x12\x12\n\nstart_date\x18\x01 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x02 \x01(\t\"\x16\n\x06\x42yHour\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\"m\n\x19RequestGetForgeStatistics\x12$\n\x08\x64\x61y_info\x18\x01 \x01(\x0b\x32\x10.forge_abi.ByDayH\x00\x12!\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.forge_abi.ByHourH\x00\x42\x07\n\x05value\"w\n\x1aResponseGetForgeStatistics\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x34\n\x10\x66orge_statistics\x18\x02 \x01(\x0b\x32\x1a.forge_abi.ForgeStatistics\"\xc9\x01\n\x17RequestListTransactions\x12$\n\x06paging\x18\x01 \x01(\x0b\x32\x14.forge_abi.PageInput\x12*\n\x0btime_filter\x18\x02 \x01(\x0b\x32\x15.forge_abi.TimeFilter\x12\x30\n\x0e\x61\x64\x64ress_filter\x18\x03 \x01(\x0b\x32\x18.forge_abi.AddressFilter\x12*\n\x0btype_filter\x18\x04 \x01(\x0b\x32\x15.forge_abi.TypeFilter\"\x97\x01\n\x18ResponseListTransactions\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12!\n\x04page\x18\x02 \x01(\x0b\x32\x13.forge_abi.PageInfo\x12\x33\n\x0ctransactions\x18\x03 \x03(\x0b\x32\x1d.forge_abi.IndexedTransaction\"\x83\x01\n\x16RequestGetAssetAddress\x12\x16\n\x0esender_address\x18\x01 \x01(\t\x12%\n\x03itx\x18\x02 \x01(\x0b\x32\x18.forge_abi.CreateAssetTx\x12*\n\x0bwallet_type\x18\x03 \x01(\x0b\x32\x15.forge_abi.WalletType\"U\n\x17ResponseGetAssetAddress\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x15\n\rasset_address\x18\x02 \x01(\t\"U\n\x0fRequestSignData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12%\n\x06wallet\x18\x02 \x01(\x0b\x32\x15.forge_abi.WalletInfo\x12\r\n\x05token\x18\x03 \x01(\t\"J\n\x10ResponseSignData\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"O\n\x10RequestGetAssets\x12$\n\x06paging\x18\x01 \x01(\x0b\x32\x14.forge_abi.PageInput\x12\x15\n\rowner_address\x18\x02 \x01(\t\"\x89\x01\n\x11ResponseGetAssets\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12!\n\x04page\x18\x02 \x01(\x0b\x32\x13.forge_abi.PageInfo\x12,\n\x06\x61ssets\x18\x03 \x03(\x0b\x32\x1c.forge_abi.IndexedAssetState\"j\n\x10RequestGetStakes\x12$\n\x06paging\x18\x01 \x01(\x0b\x32\x14.forge_abi.PageInput\x12\x30\n\x0e\x61\x64\x64ress_filter\x18\x02 \x01(\x0b\x32\x18.forge_abi.AddressFilter\"\x89\x01\n\x11ResponseGetStakes\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12!\n\x04page\x18\x02 \x01(\x0b\x32\x13.forge_abi.PageInfo\x12,\n\x06stakes\x18\x03 \x03(\x0b\x32\x1c.forge_abi.IndexedStakeState\"=\n\x15RequestGetTopAccounts\x12$\n\x06paging\x18\x01 \x01(\x0b\x32\x14.forge_abi.PageInput\"\x92\x01\n\x16ResponseGetTopAccounts\x12#\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.forge_abi.StatusCode\x12!\n\x04page\x18\x02 \x01(\x0b\x32\x13.forge_abi.PageInfo\x12\x30\n\x08\x61\x63\x63ounts\x18\x03 \x03(\x0b\x32\x1e.forge_abi.IndexedAccountStateb\x06proto3'),
    dependencies=[
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR, vendor__pb2.DESCRIPTOR, enum__pb2.DESCRIPTOR,
        type__pb2.DESCRIPTOR, state__pb2.DESCRIPTOR, tx__pb2.DESCRIPTOR, trace__type__pb2.DESCRIPTOR, ],
)


_REQUESTCREATETX = _descriptor.Descriptor(
    name='RequestCreateTx',
    full_name='forge_abi.RequestCreateTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='itx', full_name='forge_abi.RequestCreateTx.itx', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='from', full_name='forge_abi.RequestCreateTx.from', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='nonce', full_name='forge_abi.RequestCreateTx.nonce', index=2,
            number=3, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='wallet', full_name='forge_abi.RequestCreateTx.wallet', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='token', full_name='forge_abi.RequestCreateTx.token', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=131,
    serialized_end=266,
)


_RESPONSECREATETX = _descriptor.Descriptor(
    name='ResponseCreateTx',
    full_name='forge_abi.ResponseCreateTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseCreateTx.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='tx', full_name='forge_abi.ResponseCreateTx.tx', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=268,
    serialized_end=359,
)


_REQUESTMULTISIG = _descriptor.Descriptor(
    name='RequestMultisig',
    full_name='forge_abi.RequestMultisig',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tx', full_name='forge_abi.RequestMultisig.tx', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='wallet', full_name='forge_abi.RequestMultisig.wallet', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='token', full_name='forge_abi.RequestMultisig.token', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=361,
    serialized_end=468,
)


_RESPONSEMULTISIG = _descriptor.Descriptor(
    name='ResponseMultisig',
    full_name='forge_abi.ResponseMultisig',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseMultisig.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='tx', full_name='forge_abi.ResponseMultisig.tx', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=470,
    serialized_end=561,
)


_REQUESTSENDTX = _descriptor.Descriptor(
    name='RequestSendTx',
    full_name='forge_abi.RequestSendTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tx', full_name='forge_abi.RequestSendTx.tx', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='wallet', full_name='forge_abi.RequestSendTx.wallet', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='token', full_name='forge_abi.RequestSendTx.token', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='commit', full_name='forge_abi.RequestSendTx.commit', index=3,
            number=4, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=563,
    serialized_end=684,
)


_RESPONSESENDTX = _descriptor.Descriptor(
    name='ResponseSendTx',
    full_name='forge_abi.ResponseSendTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseSendTx.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='hash', full_name='forge_abi.ResponseSendTx.hash', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=686,
    serialized_end=753,
)


_REQUESTGETTX = _descriptor.Descriptor(
    name='RequestGetTx',
    full_name='forge_abi.RequestGetTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='hash', full_name='forge_abi.RequestGetTx.hash', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=755,
    serialized_end=783,
)


_RESPONSEGETTX = _descriptor.Descriptor(
    name='ResponseGetTx',
    full_name='forge_abi.ResponseGetTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetTx.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='info', full_name='forge_abi.ResponseGetTx.info', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=785,
    serialized_end=879,
)


_REQUESTGETBLOCK = _descriptor.Descriptor(
    name='RequestGetBlock',
    full_name='forge_abi.RequestGetBlock',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='height', full_name='forge_abi.RequestGetBlock.height', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=881,
    serialized_end=914,
)


_RESPONSEGETBLOCK = _descriptor.Descriptor(
    name='ResponseGetBlock',
    full_name='forge_abi.ResponseGetBlock',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetBlock.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='block', full_name='forge_abi.ResponseGetBlock.block', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=916,
    serialized_end=1008,
)


_REQUESTGETBLOCKS = _descriptor.Descriptor(
    name='RequestGetBlocks',
    full_name='forge_abi.RequestGetBlocks',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='paging', full_name='forge_abi.RequestGetBlocks.paging', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='min_height', full_name='forge_abi.RequestGetBlocks.min_height', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='max_height', full_name='forge_abi.RequestGetBlocks.max_height', index=2,
            number=3, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='empty_excluded', full_name='forge_abi.RequestGetBlocks.empty_excluded', index=3,
            number=4, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1010,
    serialized_end=1130,
)


_RESPONSEGETBLOCKS = _descriptor.Descriptor(
    name='ResponseGetBlocks',
    full_name='forge_abi.ResponseGetBlocks',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetBlocks.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='page', full_name='forge_abi.ResponseGetBlocks.page', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='blocks', full_name='forge_abi.ResponseGetBlocks.blocks', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1133,
    serialized_end=1262,
)


_REQUESTCREATEWALLET = _descriptor.Descriptor(
    name='RequestCreateWallet',
    full_name='forge_abi.RequestCreateWallet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='passphrase', full_name='forge_abi.RequestCreateWallet.passphrase', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='type', full_name='forge_abi.RequestCreateWallet.type', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='moniker', full_name='forge_abi.RequestCreateWallet.moniker', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1264,
    serialized_end=1359,
)


_RESPONSECREATEWALLET = _descriptor.Descriptor(
    name='ResponseCreateWallet',
    full_name='forge_abi.ResponseCreateWallet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseCreateWallet.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='token', full_name='forge_abi.ResponseCreateWallet.token', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='wallet', full_name='forge_abi.ResponseCreateWallet.wallet', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1361,
    serialized_end=1474,
)


_REQUESTLOADWALLET = _descriptor.Descriptor(
    name='RequestLoadWallet',
    full_name='forge_abi.RequestLoadWallet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.RequestLoadWallet.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='passphrase', full_name='forge_abi.RequestLoadWallet.passphrase', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1476,
    serialized_end=1532,
)


_RESPONSELOADWALLET = _descriptor.Descriptor(
    name='ResponseLoadWallet',
    full_name='forge_abi.ResponseLoadWallet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseLoadWallet.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='token', full_name='forge_abi.ResponseLoadWallet.token', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='wallet', full_name='forge_abi.ResponseLoadWallet.wallet', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1534,
    serialized_end=1645,
)


_REQUESTRECOVERWALLET = _descriptor.Descriptor(
    name='RequestRecoverWallet',
    full_name='forge_abi.RequestRecoverWallet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.RequestRecoverWallet.data', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='type', full_name='forge_abi.RequestRecoverWallet.type', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='passphrase', full_name='forge_abi.RequestRecoverWallet.passphrase', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='moniker', full_name='forge_abi.RequestRecoverWallet.moniker', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1647,
    serialized_end=1757,
)


_RESPONSERECOVERWALLET = _descriptor.Descriptor(
    name='ResponseRecoverWallet',
    full_name='forge_abi.ResponseRecoverWallet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseRecoverWallet.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='token', full_name='forge_abi.ResponseRecoverWallet.token', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='wallet', full_name='forge_abi.ResponseRecoverWallet.wallet', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1759,
    serialized_end=1873,
)


_REQUESTLISTWALLET = _descriptor.Descriptor(
    name='RequestListWallet',
    full_name='forge_abi.RequestListWallet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1875,
    serialized_end=1894,
)


_RESPONSELISTWALLET = _descriptor.Descriptor(
    name='ResponseListWallet',
    full_name='forge_abi.ResponseListWallet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseListWallet.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.ResponseListWallet.address', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1896,
    serialized_end=1970,
)


_REQUESTREMOVEWALLET = _descriptor.Descriptor(
    name='RequestRemoveWallet',
    full_name='forge_abi.RequestRemoveWallet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.RequestRemoveWallet.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1972,
    serialized_end=2010,
)


_RESPONSEREMOVEWALLET = _descriptor.Descriptor(
    name='ResponseRemoveWallet',
    full_name='forge_abi.ResponseRemoveWallet',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseRemoveWallet.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2012,
    serialized_end=2071,
)


_REQUESTDECLARENODE = _descriptor.Descriptor(
    name='RequestDeclareNode',
    full_name='forge_abi.RequestDeclareNode',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='validator', full_name='forge_abi.RequestDeclareNode.validator', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2073,
    serialized_end=2112,
)


_RESPONSEDECLARENODE = _descriptor.Descriptor(
    name='ResponseDeclareNode',
    full_name='forge_abi.ResponseDeclareNode',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseDeclareNode.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='wallet', full_name='forge_abi.ResponseDeclareNode.wallet', index=1,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2114,
    serialized_end=2211,
)


_REQUESTGETACCOUNTSTATE = _descriptor.Descriptor(
    name='RequestGetAccountState',
    full_name='forge_abi.RequestGetAccountState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.RequestGetAccountState.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='keys', full_name='forge_abi.RequestGetAccountState.keys', index=1,
            number=2, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_hash', full_name='forge_abi.RequestGetAccountState.app_hash', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2213,
    serialized_end=2286,
)


_RESPONSEGETACCOUNTSTATE = _descriptor.Descriptor(
    name='ResponseGetAccountState',
    full_name='forge_abi.ResponseGetAccountState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetAccountState.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='state', full_name='forge_abi.ResponseGetAccountState.state', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2288,
    serialized_end=2390,
)


_REQUESTGETASSETSTATE = _descriptor.Descriptor(
    name='RequestGetAssetState',
    full_name='forge_abi.RequestGetAssetState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.RequestGetAssetState.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='keys', full_name='forge_abi.RequestGetAssetState.keys', index=1,
            number=2, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_hash', full_name='forge_abi.RequestGetAssetState.app_hash', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2392,
    serialized_end=2463,
)


_RESPONSEGETASSETSTATE = _descriptor.Descriptor(
    name='ResponseGetAssetState',
    full_name='forge_abi.ResponseGetAssetState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetAssetState.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='state', full_name='forge_abi.ResponseGetAssetState.state', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2465,
    serialized_end=2563,
)


_REQUESTGETSTAKESTATE = _descriptor.Descriptor(
    name='RequestGetStakeState',
    full_name='forge_abi.RequestGetStakeState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='forge_abi.RequestGetStakeState.address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='keys', full_name='forge_abi.RequestGetStakeState.keys', index=1,
            number=2, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_hash', full_name='forge_abi.RequestGetStakeState.app_hash', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2565,
    serialized_end=2636,
)


_RESPONSEGETSTAKESTATE = _descriptor.Descriptor(
    name='ResponseGetStakeState',
    full_name='forge_abi.ResponseGetStakeState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetStakeState.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='state', full_name='forge_abi.ResponseGetStakeState.state', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2638,
    serialized_end=2736,
)


_REQUESTGETFORGESTATE = _descriptor.Descriptor(
    name='RequestGetForgeState',
    full_name='forge_abi.RequestGetForgeState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='keys', full_name='forge_abi.RequestGetForgeState.keys', index=0,
            number=1, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='app_hash', full_name='forge_abi.RequestGetForgeState.app_hash', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2738,
    serialized_end=2792,
)


_RESPONSEGETFORGESTATE = _descriptor.Descriptor(
    name='ResponseGetForgeState',
    full_name='forge_abi.ResponseGetForgeState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetForgeState.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='state', full_name='forge_abi.ResponseGetForgeState.state', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2794,
    serialized_end=2892,
)


_REQUESTSTOREFILE = _descriptor.Descriptor(
    name='RequestStoreFile',
    full_name='forge_abi.RequestStoreFile',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='chunk', full_name='forge_abi.RequestStoreFile.chunk', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2894,
    serialized_end=2927,
)


_RESPONSESTOREFILE = _descriptor.Descriptor(
    name='ResponseStoreFile',
    full_name='forge_abi.ResponseStoreFile',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseStoreFile.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='hash', full_name='forge_abi.ResponseStoreFile.hash', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2929,
    serialized_end=2999,
)


_REQUESTLOADFILE = _descriptor.Descriptor(
    name='RequestLoadFile',
    full_name='forge_abi.RequestLoadFile',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='hash', full_name='forge_abi.RequestLoadFile.hash', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3001,
    serialized_end=3032,
)


_RESPONSELOADFILE = _descriptor.Descriptor(
    name='ResponseLoadFile',
    full_name='forge_abi.ResponseLoadFile',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseLoadFile.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='chunk', full_name='forge_abi.ResponseLoadFile.chunk', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3034,
    serialized_end=3104,
)


_REQUESTPINFILE = _descriptor.Descriptor(
    name='RequestPinFile',
    full_name='forge_abi.RequestPinFile',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='hash', full_name='forge_abi.RequestPinFile.hash', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3106,
    serialized_end=3136,
)


_RESPONSEPINFILE = _descriptor.Descriptor(
    name='ResponsePinFile',
    full_name='forge_abi.ResponsePinFile',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponsePinFile.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3138,
    serialized_end=3192,
)


_REQUESTGETCHAININFO = _descriptor.Descriptor(
    name='RequestGetChainInfo',
    full_name='forge_abi.RequestGetChainInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3194,
    serialized_end=3215,
)


_RESPONSEGETCHAININFO = _descriptor.Descriptor(
    name='ResponseGetChainInfo',
    full_name='forge_abi.ResponseGetChainInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetChainInfo.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='info', full_name='forge_abi.ResponseGetChainInfo.info', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3217,
    serialized_end=3312,
)


_REQUESTSEARCH = _descriptor.Descriptor(
    name='RequestSearch',
    full_name='forge_abi.RequestSearch',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='forge_abi.RequestSearch.key', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='value', full_name='forge_abi.RequestSearch.value', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3314,
    serialized_end=3357,
)


_RESPONSESEARCH = _descriptor.Descriptor(
    name='ResponseSearch',
    full_name='forge_abi.ResponseSearch',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseSearch.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='txs', full_name='forge_abi.ResponseSearch.txs', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3359,
    serialized_end=3453,
)


_REQUESTGETUNCONFIRMEDTXS = _descriptor.Descriptor(
    name='RequestGetUnconfirmedTxs',
    full_name='forge_abi.RequestGetUnconfirmedTxs',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='limit', full_name='forge_abi.RequestGetUnconfirmedTxs.limit', index=0,
            number=1, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3455,
    serialized_end=3496,
)


_RESPONSEGETUNCONFIRMEDTXS = _descriptor.Descriptor(
    name='ResponseGetUnconfirmedTxs',
    full_name='forge_abi.ResponseGetUnconfirmedTxs',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetUnconfirmedTxs.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='unconfirmed_txs', full_name='forge_abi.ResponseGetUnconfirmedTxs.unconfirmed_txs', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3498,
    serialized_end=3614,
)


_REQUESTGETNETINFO = _descriptor.Descriptor(
    name='RequestGetNetInfo',
    full_name='forge_abi.RequestGetNetInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3616,
    serialized_end=3635,
)


_RESPONSEGETNETINFO = _descriptor.Descriptor(
    name='ResponseGetNetInfo',
    full_name='forge_abi.ResponseGetNetInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetNetInfo.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='net_info', full_name='forge_abi.ResponseGetNetInfo.net_info', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3637,
    serialized_end=3732,
)


_REQUESTGETVALIDATORSINFO = _descriptor.Descriptor(
    name='RequestGetValidatorsInfo',
    full_name='forge_abi.RequestGetValidatorsInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3734,
    serialized_end=3760,
)


_RESPONSEGETVALIDATORSINFO = _descriptor.Descriptor(
    name='ResponseGetValidatorsInfo',
    full_name='forge_abi.ResponseGetValidatorsInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetValidatorsInfo.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='validators_info', full_name='forge_abi.ResponseGetValidatorsInfo.validators_info', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3762,
    serialized_end=3878,
)


_REQUESTSUBSCRIBE = _descriptor.Descriptor(
    name='RequestSubscribe',
    full_name='forge_abi.RequestSubscribe',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='forge_abi.RequestSubscribe.type', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='filter', full_name='forge_abi.RequestSubscribe.filter', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3880,
    serialized_end=3950,
)


_RESPONSESUBSCRIBE = _descriptor.Descriptor(
    name='ResponseSubscribe',
    full_name='forge_abi.ResponseSubscribe',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseSubscribe.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='topic', full_name='forge_abi.ResponseSubscribe.topic', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='transfer', full_name='forge_abi.ResponseSubscribe.transfer', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='account_migrate', full_name='forge_abi.ResponseSubscribe.account_migrate', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='confirm', full_name='forge_abi.ResponseSubscribe.confirm', index=4,
            number=5, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='create_asset', full_name='forge_abi.ResponseSubscribe.create_asset', index=5,
            number=6, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='exchange', full_name='forge_abi.ResponseSubscribe.exchange', index=6,
            number=7, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='revoke', full_name='forge_abi.ResponseSubscribe.revoke', index=7,
            number=8, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='begin_block', full_name='forge_abi.ResponseSubscribe.begin_block', index=8,
            number=16, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='end_block', full_name='forge_abi.ResponseSubscribe.end_block', index=9,
            number=17, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='declare', full_name='forge_abi.ResponseSubscribe.declare', index=10,
            number=19, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='update_asset', full_name='forge_abi.ResponseSubscribe.update_asset', index=11,
            number=20, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='consensus_upgrade', full_name='forge_abi.ResponseSubscribe.consensus_upgrade', index=12,
            number=21, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='declare_file', full_name='forge_abi.ResponseSubscribe.declare_file', index=13,
            number=22, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='sys_upgrade', full_name='forge_abi.ResponseSubscribe.sys_upgrade', index=14,
            number=23, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='stake', full_name='forge_abi.ResponseSubscribe.stake', index=15,
            number=24, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='account_state', full_name='forge_abi.ResponseSubscribe.account_state', index=16,
            number=129, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='asset_state', full_name='forge_abi.ResponseSubscribe.asset_state', index=17,
            number=130, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='forge_state', full_name='forge_abi.ResponseSubscribe.forge_state', index=18,
            number=131, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='stake_state', full_name='forge_abi.ResponseSubscribe.stake_state', index=19,
            number=132, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='value', full_name='forge_abi.ResponseSubscribe.value',
            index=0, containing_type=None, fields=[],
        ),
    ],
    serialized_start=3953,
    serialized_end=4887,
)


_REQUESTUNSUBSCRIBE = _descriptor.Descriptor(
    name='RequestUnsubscribe',
    full_name='forge_abi.RequestUnsubscribe',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='topic', full_name='forge_abi.RequestUnsubscribe.topic', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4889,
    serialized_end=4924,
)


_RESPONSEUNSUBSCRIBE = _descriptor.Descriptor(
    name='ResponseUnsubscribe',
    full_name='forge_abi.ResponseUnsubscribe',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseUnsubscribe.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4926,
    serialized_end=4984,
)


_REQUESTGETCONFIG = _descriptor.Descriptor(
    name='RequestGetConfig',
    full_name='forge_abi.RequestGetConfig',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4986,
    serialized_end=5004,
)


_RESPONSEGETCONFIG = _descriptor.Descriptor(
    name='ResponseGetConfig',
    full_name='forge_abi.ResponseGetConfig',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetConfig.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='config', full_name='forge_abi.ResponseGetConfig.config', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=5006,
    serialized_end=5078,
)


_BYDAY = _descriptor.Descriptor(
    name='ByDay',
    full_name='forge_abi.ByDay',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='start_date', full_name='forge_abi.ByDay.start_date', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='end_date', full_name='forge_abi.ByDay.end_date', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=5080,
    serialized_end=5125,
)


_BYHOUR = _descriptor.Descriptor(
    name='ByHour',
    full_name='forge_abi.ByHour',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='date', full_name='forge_abi.ByHour.date', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=5127,
    serialized_end=5149,
)


_REQUESTGETFORGESTATISTICS = _descriptor.Descriptor(
    name='RequestGetForgeStatistics',
    full_name='forge_abi.RequestGetForgeStatistics',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='day_info', full_name='forge_abi.RequestGetForgeStatistics.day_info', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='date', full_name='forge_abi.RequestGetForgeStatistics.date', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='value', full_name='forge_abi.RequestGetForgeStatistics.value',
            index=0, containing_type=None, fields=[],
        ),
    ],
    serialized_start=5151,
    serialized_end=5260,
)


_RESPONSEGETFORGESTATISTICS = _descriptor.Descriptor(
    name='ResponseGetForgeStatistics',
    full_name='forge_abi.ResponseGetForgeStatistics',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetForgeStatistics.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='forge_statistics', full_name='forge_abi.ResponseGetForgeStatistics.forge_statistics', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=5262,
    serialized_end=5381,
)


_REQUESTLISTTRANSACTIONS = _descriptor.Descriptor(
    name='RequestListTransactions',
    full_name='forge_abi.RequestListTransactions',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='paging', full_name='forge_abi.RequestListTransactions.paging', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='time_filter', full_name='forge_abi.RequestListTransactions.time_filter', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='address_filter', full_name='forge_abi.RequestListTransactions.address_filter', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='type_filter', full_name='forge_abi.RequestListTransactions.type_filter', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=5384,
    serialized_end=5585,
)


_RESPONSELISTTRANSACTIONS = _descriptor.Descriptor(
    name='ResponseListTransactions',
    full_name='forge_abi.ResponseListTransactions',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseListTransactions.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='page', full_name='forge_abi.ResponseListTransactions.page', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='transactions', full_name='forge_abi.ResponseListTransactions.transactions', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=5588,
    serialized_end=5739,
)


_REQUESTGETASSETADDRESS = _descriptor.Descriptor(
    name='RequestGetAssetAddress',
    full_name='forge_abi.RequestGetAssetAddress',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='sender_address', full_name='forge_abi.RequestGetAssetAddress.sender_address', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='itx', full_name='forge_abi.RequestGetAssetAddress.itx', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='wallet_type', full_name='forge_abi.RequestGetAssetAddress.wallet_type', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=5742,
    serialized_end=5873,
)


_RESPONSEGETASSETADDRESS = _descriptor.Descriptor(
    name='ResponseGetAssetAddress',
    full_name='forge_abi.ResponseGetAssetAddress',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetAssetAddress.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='asset_address', full_name='forge_abi.ResponseGetAssetAddress.asset_address', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=5875,
    serialized_end=5960,
)


_REQUESTSIGNDATA = _descriptor.Descriptor(
    name='RequestSignData',
    full_name='forge_abi.RequestSignData',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='data', full_name='forge_abi.RequestSignData.data', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='wallet', full_name='forge_abi.RequestSignData.wallet', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='token', full_name='forge_abi.RequestSignData.token', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=5962,
    serialized_end=6047,
)


_RESPONSESIGNDATA = _descriptor.Descriptor(
    name='ResponseSignData',
    full_name='forge_abi.ResponseSignData',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseSignData.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='signature', full_name='forge_abi.ResponseSignData.signature', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=6049,
    serialized_end=6123,
)


_REQUESTGETASSETS = _descriptor.Descriptor(
    name='RequestGetAssets',
    full_name='forge_abi.RequestGetAssets',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='paging', full_name='forge_abi.RequestGetAssets.paging', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='owner_address', full_name='forge_abi.RequestGetAssets.owner_address', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=6125,
    serialized_end=6204,
)


_RESPONSEGETASSETS = _descriptor.Descriptor(
    name='ResponseGetAssets',
    full_name='forge_abi.ResponseGetAssets',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetAssets.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='page', full_name='forge_abi.ResponseGetAssets.page', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='assets', full_name='forge_abi.ResponseGetAssets.assets', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=6207,
    serialized_end=6344,
)


_REQUESTGETSTAKES = _descriptor.Descriptor(
    name='RequestGetStakes',
    full_name='forge_abi.RequestGetStakes',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='paging', full_name='forge_abi.RequestGetStakes.paging', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='address_filter', full_name='forge_abi.RequestGetStakes.address_filter', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=6346,
    serialized_end=6452,
)


_RESPONSEGETSTAKES = _descriptor.Descriptor(
    name='ResponseGetStakes',
    full_name='forge_abi.ResponseGetStakes',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetStakes.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='page', full_name='forge_abi.ResponseGetStakes.page', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='stakes', full_name='forge_abi.ResponseGetStakes.stakes', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=6455,
    serialized_end=6592,
)


_REQUESTGETTOPACCOUNTS = _descriptor.Descriptor(
    name='RequestGetTopAccounts',
    full_name='forge_abi.RequestGetTopAccounts',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='paging', full_name='forge_abi.RequestGetTopAccounts.paging', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=6594,
    serialized_end=6655,
)


_RESPONSEGETTOPACCOUNTS = _descriptor.Descriptor(
    name='ResponseGetTopAccounts',
    full_name='forge_abi.ResponseGetTopAccounts',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='forge_abi.ResponseGetTopAccounts.code', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='page', full_name='forge_abi.ResponseGetTopAccounts.page', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='accounts', full_name='forge_abi.ResponseGetTopAccounts.accounts', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=6658,
    serialized_end=6804,
)

_REQUESTCREATETX.fields_by_name['itx'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_REQUESTCREATETX.fields_by_name['wallet'].message_type = type__pb2._WALLETINFO
_RESPONSECREATETX.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSECREATETX.fields_by_name['tx'].message_type = type__pb2._TRANSACTION
_REQUESTMULTISIG.fields_by_name['tx'].message_type = type__pb2._TRANSACTION
_REQUESTMULTISIG.fields_by_name['wallet'].message_type = type__pb2._WALLETINFO
_RESPONSEMULTISIG.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEMULTISIG.fields_by_name['tx'].message_type = type__pb2._TRANSACTION
_REQUESTSENDTX.fields_by_name['tx'].message_type = type__pb2._TRANSACTION
_REQUESTSENDTX.fields_by_name['wallet'].message_type = type__pb2._WALLETINFO
_RESPONSESENDTX.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETTX.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETTX.fields_by_name['info'].message_type = type__pb2._TRANSACTIONINFO
_RESPONSEGETBLOCK.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETBLOCK.fields_by_name['block'].message_type = type__pb2._BLOCKINFO
_REQUESTGETBLOCKS.fields_by_name['paging'].message_type = trace__type__pb2._PAGEINPUT
_RESPONSEGETBLOCKS.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETBLOCKS.fields_by_name['page'].message_type = trace__type__pb2._PAGEINFO
_RESPONSEGETBLOCKS.fields_by_name['blocks'].message_type = type__pb2._BLOCKINFO
_REQUESTCREATEWALLET.fields_by_name['type'].message_type = type__pb2._WALLETTYPE
_RESPONSECREATEWALLET.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSECREATEWALLET.fields_by_name['wallet'].message_type = type__pb2._WALLETINFO
_RESPONSELOADWALLET.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSELOADWALLET.fields_by_name['wallet'].message_type = type__pb2._WALLETINFO
_REQUESTRECOVERWALLET.fields_by_name['type'].message_type = type__pb2._WALLETTYPE
_RESPONSERECOVERWALLET.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSERECOVERWALLET.fields_by_name['wallet'].message_type = type__pb2._WALLETINFO
_RESPONSELISTWALLET.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEREMOVEWALLET.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEDECLARENODE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEDECLARENODE.fields_by_name['wallet'].message_type = type__pb2._WALLETINFO
_RESPONSEGETACCOUNTSTATE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETACCOUNTSTATE.fields_by_name['state'].message_type = state__pb2._ACCOUNTSTATE
_RESPONSEGETASSETSTATE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETASSETSTATE.fields_by_name['state'].message_type = state__pb2._ASSETSTATE
_RESPONSEGETSTAKESTATE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETSTAKESTATE.fields_by_name['state'].message_type = state__pb2._STAKESTATE
_RESPONSEGETFORGESTATE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETFORGESTATE.fields_by_name['state'].message_type = state__pb2._FORGESTATE
_RESPONSESTOREFILE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSELOADFILE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEPINFILE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETCHAININFO.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETCHAININFO.fields_by_name['info'].message_type = type__pb2._CHAININFO
_RESPONSESEARCH.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSESEARCH.fields_by_name['txs'].message_type = type__pb2._TRANSACTIONINFO
_RESPONSEGETUNCONFIRMEDTXS.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETUNCONFIRMEDTXS.fields_by_name['unconfirmed_txs'].message_type = type__pb2._UNCONFIRMEDTXS
_RESPONSEGETNETINFO.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETNETINFO.fields_by_name['net_info'].message_type = type__pb2._NETINFO
_RESPONSEGETVALIDATORSINFO.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETVALIDATORSINFO.fields_by_name['validators_info'].message_type = type__pb2._VALIDATORSINFO
_REQUESTSUBSCRIBE.fields_by_name['type'].enum_type = enum__pb2._TOPICTYPE
_RESPONSESUBSCRIBE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSESUBSCRIBE.fields_by_name['transfer'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['account_migrate'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['confirm'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['create_asset'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['exchange'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['revoke'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['begin_block'].message_type = vendor__pb2._REQUESTBEGINBLOCK
_RESPONSESUBSCRIBE.fields_by_name['end_block'].message_type = vendor__pb2._REQUESTENDBLOCK
_RESPONSESUBSCRIBE.fields_by_name['declare'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['update_asset'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['consensus_upgrade'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['declare_file'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['sys_upgrade'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['stake'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['account_state'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['asset_state'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['forge_state'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.fields_by_name['stake_state'].message_type = type__pb2._TRANSACTION
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['topic'],
)
_RESPONSESUBSCRIBE.fields_by_name['topic'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['transfer'],
)
_RESPONSESUBSCRIBE.fields_by_name['transfer'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['account_migrate'],
)
_RESPONSESUBSCRIBE.fields_by_name['account_migrate'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['confirm'],
)
_RESPONSESUBSCRIBE.fields_by_name['confirm'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['create_asset'],
)
_RESPONSESUBSCRIBE.fields_by_name['create_asset'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['exchange'],
)
_RESPONSESUBSCRIBE.fields_by_name['exchange'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['revoke'],
)
_RESPONSESUBSCRIBE.fields_by_name['revoke'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['begin_block'],
)
_RESPONSESUBSCRIBE.fields_by_name['begin_block'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['end_block'],
)
_RESPONSESUBSCRIBE.fields_by_name['end_block'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['declare'],
)
_RESPONSESUBSCRIBE.fields_by_name['declare'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['update_asset'],
)
_RESPONSESUBSCRIBE.fields_by_name['update_asset'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['consensus_upgrade'],
)
_RESPONSESUBSCRIBE.fields_by_name['consensus_upgrade'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['declare_file'],
)
_RESPONSESUBSCRIBE.fields_by_name['declare_file'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['sys_upgrade'],
)
_RESPONSESUBSCRIBE.fields_by_name['sys_upgrade'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['stake'],
)
_RESPONSESUBSCRIBE.fields_by_name['stake'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['account_state'],
)
_RESPONSESUBSCRIBE.fields_by_name['account_state'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['asset_state'],
)
_RESPONSESUBSCRIBE.fields_by_name['asset_state'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['forge_state'],
)
_RESPONSESUBSCRIBE.fields_by_name['forge_state'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSESUBSCRIBE.oneofs_by_name['value'].fields.append(
    _RESPONSESUBSCRIBE.fields_by_name['stake_state'],
)
_RESPONSESUBSCRIBE.fields_by_name['stake_state'].containing_oneof = _RESPONSESUBSCRIBE.oneofs_by_name['value']
_RESPONSEUNSUBSCRIBE.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETCONFIG.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_REQUESTGETFORGESTATISTICS.fields_by_name['day_info'].message_type = _BYDAY
_REQUESTGETFORGESTATISTICS.fields_by_name['date'].message_type = _BYHOUR
_REQUESTGETFORGESTATISTICS.oneofs_by_name['value'].fields.append(
    _REQUESTGETFORGESTATISTICS.fields_by_name['day_info'],
)
_REQUESTGETFORGESTATISTICS.fields_by_name['day_info'].containing_oneof = _REQUESTGETFORGESTATISTICS.oneofs_by_name['value']
_REQUESTGETFORGESTATISTICS.oneofs_by_name['value'].fields.append(
    _REQUESTGETFORGESTATISTICS.fields_by_name['date'],
)
_REQUESTGETFORGESTATISTICS.fields_by_name['date'].containing_oneof = _REQUESTGETFORGESTATISTICS.oneofs_by_name['value']
_RESPONSEGETFORGESTATISTICS.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETFORGESTATISTICS.fields_by_name['forge_statistics'].message_type = type__pb2._FORGESTATISTICS
_REQUESTLISTTRANSACTIONS.fields_by_name['paging'].message_type = trace__type__pb2._PAGEINPUT
_REQUESTLISTTRANSACTIONS.fields_by_name['time_filter'].message_type = trace__type__pb2._TIMEFILTER
_REQUESTLISTTRANSACTIONS.fields_by_name['address_filter'].message_type = trace__type__pb2._ADDRESSFILTER
_REQUESTLISTTRANSACTIONS.fields_by_name['type_filter'].message_type = trace__type__pb2._TYPEFILTER
_RESPONSELISTTRANSACTIONS.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSELISTTRANSACTIONS.fields_by_name['page'].message_type = trace__type__pb2._PAGEINFO
_RESPONSELISTTRANSACTIONS.fields_by_name['transactions'].message_type = trace__type__pb2._INDEXEDTRANSACTION
_REQUESTGETASSETADDRESS.fields_by_name['itx'].message_type = tx__pb2._CREATEASSETTX
_REQUESTGETASSETADDRESS.fields_by_name['wallet_type'].message_type = type__pb2._WALLETTYPE
_RESPONSEGETASSETADDRESS.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_REQUESTSIGNDATA.fields_by_name['wallet'].message_type = type__pb2._WALLETINFO
_RESPONSESIGNDATA.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_REQUESTGETASSETS.fields_by_name['paging'].message_type = trace__type__pb2._PAGEINPUT
_RESPONSEGETASSETS.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETASSETS.fields_by_name['page'].message_type = trace__type__pb2._PAGEINFO
_RESPONSEGETASSETS.fields_by_name['assets'].message_type = trace__type__pb2._INDEXEDASSETSTATE
_REQUESTGETSTAKES.fields_by_name['paging'].message_type = trace__type__pb2._PAGEINPUT
_REQUESTGETSTAKES.fields_by_name['address_filter'].message_type = trace__type__pb2._ADDRESSFILTER
_RESPONSEGETSTAKES.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETSTAKES.fields_by_name['page'].message_type = trace__type__pb2._PAGEINFO
_RESPONSEGETSTAKES.fields_by_name['stakes'].message_type = trace__type__pb2._INDEXEDSTAKESTATE
_REQUESTGETTOPACCOUNTS.fields_by_name['paging'].message_type = trace__type__pb2._PAGEINPUT
_RESPONSEGETTOPACCOUNTS.fields_by_name['code'].enum_type = enum__pb2._STATUSCODE
_RESPONSEGETTOPACCOUNTS.fields_by_name['page'].message_type = trace__type__pb2._PAGEINFO
_RESPONSEGETTOPACCOUNTS.fields_by_name['accounts'].message_type = trace__type__pb2._INDEXEDACCOUNTSTATE
DESCRIPTOR.message_types_by_name['RequestCreateTx'] = _REQUESTCREATETX
DESCRIPTOR.message_types_by_name['ResponseCreateTx'] = _RESPONSECREATETX
DESCRIPTOR.message_types_by_name['RequestMultisig'] = _REQUESTMULTISIG
DESCRIPTOR.message_types_by_name['ResponseMultisig'] = _RESPONSEMULTISIG
DESCRIPTOR.message_types_by_name['RequestSendTx'] = _REQUESTSENDTX
DESCRIPTOR.message_types_by_name['ResponseSendTx'] = _RESPONSESENDTX
DESCRIPTOR.message_types_by_name['RequestGetTx'] = _REQUESTGETTX
DESCRIPTOR.message_types_by_name['ResponseGetTx'] = _RESPONSEGETTX
DESCRIPTOR.message_types_by_name['RequestGetBlock'] = _REQUESTGETBLOCK
DESCRIPTOR.message_types_by_name['ResponseGetBlock'] = _RESPONSEGETBLOCK
DESCRIPTOR.message_types_by_name['RequestGetBlocks'] = _REQUESTGETBLOCKS
DESCRIPTOR.message_types_by_name['ResponseGetBlocks'] = _RESPONSEGETBLOCKS
DESCRIPTOR.message_types_by_name['RequestCreateWallet'] = _REQUESTCREATEWALLET
DESCRIPTOR.message_types_by_name['ResponseCreateWallet'] = _RESPONSECREATEWALLET
DESCRIPTOR.message_types_by_name['RequestLoadWallet'] = _REQUESTLOADWALLET
DESCRIPTOR.message_types_by_name['ResponseLoadWallet'] = _RESPONSELOADWALLET
DESCRIPTOR.message_types_by_name['RequestRecoverWallet'] = _REQUESTRECOVERWALLET
DESCRIPTOR.message_types_by_name['ResponseRecoverWallet'] = _RESPONSERECOVERWALLET
DESCRIPTOR.message_types_by_name['RequestListWallet'] = _REQUESTLISTWALLET
DESCRIPTOR.message_types_by_name['ResponseListWallet'] = _RESPONSELISTWALLET
DESCRIPTOR.message_types_by_name['RequestRemoveWallet'] = _REQUESTREMOVEWALLET
DESCRIPTOR.message_types_by_name['ResponseRemoveWallet'] = _RESPONSEREMOVEWALLET
DESCRIPTOR.message_types_by_name['RequestDeclareNode'] = _REQUESTDECLARENODE
DESCRIPTOR.message_types_by_name['ResponseDeclareNode'] = _RESPONSEDECLARENODE
DESCRIPTOR.message_types_by_name['RequestGetAccountState'] = _REQUESTGETACCOUNTSTATE
DESCRIPTOR.message_types_by_name['ResponseGetAccountState'] = _RESPONSEGETACCOUNTSTATE
DESCRIPTOR.message_types_by_name['RequestGetAssetState'] = _REQUESTGETASSETSTATE
DESCRIPTOR.message_types_by_name['ResponseGetAssetState'] = _RESPONSEGETASSETSTATE
DESCRIPTOR.message_types_by_name['RequestGetStakeState'] = _REQUESTGETSTAKESTATE
DESCRIPTOR.message_types_by_name['ResponseGetStakeState'] = _RESPONSEGETSTAKESTATE
DESCRIPTOR.message_types_by_name['RequestGetForgeState'] = _REQUESTGETFORGESTATE
DESCRIPTOR.message_types_by_name['ResponseGetForgeState'] = _RESPONSEGETFORGESTATE
DESCRIPTOR.message_types_by_name['RequestStoreFile'] = _REQUESTSTOREFILE
DESCRIPTOR.message_types_by_name['ResponseStoreFile'] = _RESPONSESTOREFILE
DESCRIPTOR.message_types_by_name['RequestLoadFile'] = _REQUESTLOADFILE
DESCRIPTOR.message_types_by_name['ResponseLoadFile'] = _RESPONSELOADFILE
DESCRIPTOR.message_types_by_name['RequestPinFile'] = _REQUESTPINFILE
DESCRIPTOR.message_types_by_name['ResponsePinFile'] = _RESPONSEPINFILE
DESCRIPTOR.message_types_by_name['RequestGetChainInfo'] = _REQUESTGETCHAININFO
DESCRIPTOR.message_types_by_name['ResponseGetChainInfo'] = _RESPONSEGETCHAININFO
DESCRIPTOR.message_types_by_name['RequestSearch'] = _REQUESTSEARCH
DESCRIPTOR.message_types_by_name['ResponseSearch'] = _RESPONSESEARCH
DESCRIPTOR.message_types_by_name['RequestGetUnconfirmedTxs'] = _REQUESTGETUNCONFIRMEDTXS
DESCRIPTOR.message_types_by_name['ResponseGetUnconfirmedTxs'] = _RESPONSEGETUNCONFIRMEDTXS
DESCRIPTOR.message_types_by_name['RequestGetNetInfo'] = _REQUESTGETNETINFO
DESCRIPTOR.message_types_by_name['ResponseGetNetInfo'] = _RESPONSEGETNETINFO
DESCRIPTOR.message_types_by_name['RequestGetValidatorsInfo'] = _REQUESTGETVALIDATORSINFO
DESCRIPTOR.message_types_by_name['ResponseGetValidatorsInfo'] = _RESPONSEGETVALIDATORSINFO
DESCRIPTOR.message_types_by_name['RequestSubscribe'] = _REQUESTSUBSCRIBE
DESCRIPTOR.message_types_by_name['ResponseSubscribe'] = _RESPONSESUBSCRIBE
DESCRIPTOR.message_types_by_name['RequestUnsubscribe'] = _REQUESTUNSUBSCRIBE
DESCRIPTOR.message_types_by_name['ResponseUnsubscribe'] = _RESPONSEUNSUBSCRIBE
DESCRIPTOR.message_types_by_name['RequestGetConfig'] = _REQUESTGETCONFIG
DESCRIPTOR.message_types_by_name['ResponseGetConfig'] = _RESPONSEGETCONFIG
DESCRIPTOR.message_types_by_name['ByDay'] = _BYDAY
DESCRIPTOR.message_types_by_name['ByHour'] = _BYHOUR
DESCRIPTOR.message_types_by_name['RequestGetForgeStatistics'] = _REQUESTGETFORGESTATISTICS
DESCRIPTOR.message_types_by_name['ResponseGetForgeStatistics'] = _RESPONSEGETFORGESTATISTICS
DESCRIPTOR.message_types_by_name['RequestListTransactions'] = _REQUESTLISTTRANSACTIONS
DESCRIPTOR.message_types_by_name['ResponseListTransactions'] = _RESPONSELISTTRANSACTIONS
DESCRIPTOR.message_types_by_name['RequestGetAssetAddress'] = _REQUESTGETASSETADDRESS
DESCRIPTOR.message_types_by_name['ResponseGetAssetAddress'] = _RESPONSEGETASSETADDRESS
DESCRIPTOR.message_types_by_name['RequestSignData'] = _REQUESTSIGNDATA
DESCRIPTOR.message_types_by_name['ResponseSignData'] = _RESPONSESIGNDATA
DESCRIPTOR.message_types_by_name['RequestGetAssets'] = _REQUESTGETASSETS
DESCRIPTOR.message_types_by_name['ResponseGetAssets'] = _RESPONSEGETASSETS
DESCRIPTOR.message_types_by_name['RequestGetStakes'] = _REQUESTGETSTAKES
DESCRIPTOR.message_types_by_name['ResponseGetStakes'] = _RESPONSEGETSTAKES
DESCRIPTOR.message_types_by_name['RequestGetTopAccounts'] = _REQUESTGETTOPACCOUNTS
DESCRIPTOR.message_types_by_name['ResponseGetTopAccounts'] = _RESPONSEGETTOPACCOUNTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestCreateTx = _reflection.GeneratedProtocolMessageType(
    'RequestCreateTx', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTCREATETX,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestCreateTx)
    ),
)
_sym_db.RegisterMessage(RequestCreateTx)

ResponseCreateTx = _reflection.GeneratedProtocolMessageType(
    'ResponseCreateTx', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSECREATETX,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseCreateTx)
    ),
)
_sym_db.RegisterMessage(ResponseCreateTx)

RequestMultisig = _reflection.GeneratedProtocolMessageType(
    'RequestMultisig', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTMULTISIG,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestMultisig)
    ),
)
_sym_db.RegisterMessage(RequestMultisig)

ResponseMultisig = _reflection.GeneratedProtocolMessageType(
    'ResponseMultisig', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEMULTISIG,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseMultisig)
    ),
)
_sym_db.RegisterMessage(ResponseMultisig)

RequestSendTx = _reflection.GeneratedProtocolMessageType(
    'RequestSendTx', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTSENDTX,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestSendTx)
    ),
)
_sym_db.RegisterMessage(RequestSendTx)

ResponseSendTx = _reflection.GeneratedProtocolMessageType(
    'ResponseSendTx', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSESENDTX,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseSendTx)
    ),
)
_sym_db.RegisterMessage(ResponseSendTx)

RequestGetTx = _reflection.GeneratedProtocolMessageType(
    'RequestGetTx', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETTX,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetTx)
    ),
)
_sym_db.RegisterMessage(RequestGetTx)

ResponseGetTx = _reflection.GeneratedProtocolMessageType(
    'ResponseGetTx', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETTX,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetTx)
    ),
)
_sym_db.RegisterMessage(ResponseGetTx)

RequestGetBlock = _reflection.GeneratedProtocolMessageType(
    'RequestGetBlock', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETBLOCK,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetBlock)
    ),
)
_sym_db.RegisterMessage(RequestGetBlock)

ResponseGetBlock = _reflection.GeneratedProtocolMessageType(
    'ResponseGetBlock', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETBLOCK,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetBlock)
    ),
)
_sym_db.RegisterMessage(ResponseGetBlock)

RequestGetBlocks = _reflection.GeneratedProtocolMessageType(
    'RequestGetBlocks', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETBLOCKS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetBlocks)
    ),
)
_sym_db.RegisterMessage(RequestGetBlocks)

ResponseGetBlocks = _reflection.GeneratedProtocolMessageType(
    'ResponseGetBlocks', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETBLOCKS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetBlocks)
    ),
)
_sym_db.RegisterMessage(ResponseGetBlocks)

RequestCreateWallet = _reflection.GeneratedProtocolMessageType(
    'RequestCreateWallet', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTCREATEWALLET,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestCreateWallet)
    ),
)
_sym_db.RegisterMessage(RequestCreateWallet)

ResponseCreateWallet = _reflection.GeneratedProtocolMessageType(
    'ResponseCreateWallet', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSECREATEWALLET,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseCreateWallet)
    ),
)
_sym_db.RegisterMessage(ResponseCreateWallet)

RequestLoadWallet = _reflection.GeneratedProtocolMessageType(
    'RequestLoadWallet', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTLOADWALLET,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestLoadWallet)
    ),
)
_sym_db.RegisterMessage(RequestLoadWallet)

ResponseLoadWallet = _reflection.GeneratedProtocolMessageType(
    'ResponseLoadWallet', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSELOADWALLET,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseLoadWallet)
    ),
)
_sym_db.RegisterMessage(ResponseLoadWallet)

RequestRecoverWallet = _reflection.GeneratedProtocolMessageType(
    'RequestRecoverWallet', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTRECOVERWALLET,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestRecoverWallet)
    ),
)
_sym_db.RegisterMessage(RequestRecoverWallet)

ResponseRecoverWallet = _reflection.GeneratedProtocolMessageType(
    'ResponseRecoverWallet', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSERECOVERWALLET,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseRecoverWallet)
    ),
)
_sym_db.RegisterMessage(ResponseRecoverWallet)

RequestListWallet = _reflection.GeneratedProtocolMessageType(
    'RequestListWallet', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTLISTWALLET,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestListWallet)
    ),
)
_sym_db.RegisterMessage(RequestListWallet)

ResponseListWallet = _reflection.GeneratedProtocolMessageType(
    'ResponseListWallet', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSELISTWALLET,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseListWallet)
    ),
)
_sym_db.RegisterMessage(ResponseListWallet)

RequestRemoveWallet = _reflection.GeneratedProtocolMessageType(
    'RequestRemoveWallet', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTREMOVEWALLET,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestRemoveWallet)
    ),
)
_sym_db.RegisterMessage(RequestRemoveWallet)

ResponseRemoveWallet = _reflection.GeneratedProtocolMessageType(
    'ResponseRemoveWallet', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEREMOVEWALLET,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseRemoveWallet)
    ),
)
_sym_db.RegisterMessage(ResponseRemoveWallet)

RequestDeclareNode = _reflection.GeneratedProtocolMessageType(
    'RequestDeclareNode', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTDECLARENODE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestDeclareNode)
    ),
)
_sym_db.RegisterMessage(RequestDeclareNode)

ResponseDeclareNode = _reflection.GeneratedProtocolMessageType(
    'ResponseDeclareNode', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEDECLARENODE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseDeclareNode)
    ),
)
_sym_db.RegisterMessage(ResponseDeclareNode)

RequestGetAccountState = _reflection.GeneratedProtocolMessageType(
    'RequestGetAccountState', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETACCOUNTSTATE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetAccountState)
    ),
)
_sym_db.RegisterMessage(RequestGetAccountState)

ResponseGetAccountState = _reflection.GeneratedProtocolMessageType(
    'ResponseGetAccountState', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETACCOUNTSTATE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetAccountState)
    ),
)
_sym_db.RegisterMessage(ResponseGetAccountState)

RequestGetAssetState = _reflection.GeneratedProtocolMessageType(
    'RequestGetAssetState', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETASSETSTATE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetAssetState)
    ),
)
_sym_db.RegisterMessage(RequestGetAssetState)

ResponseGetAssetState = _reflection.GeneratedProtocolMessageType(
    'ResponseGetAssetState', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETASSETSTATE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetAssetState)
    ),
)
_sym_db.RegisterMessage(ResponseGetAssetState)

RequestGetStakeState = _reflection.GeneratedProtocolMessageType(
    'RequestGetStakeState', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETSTAKESTATE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetStakeState)
    ),
)
_sym_db.RegisterMessage(RequestGetStakeState)

ResponseGetStakeState = _reflection.GeneratedProtocolMessageType(
    'ResponseGetStakeState', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETSTAKESTATE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetStakeState)
    ),
)
_sym_db.RegisterMessage(ResponseGetStakeState)

RequestGetForgeState = _reflection.GeneratedProtocolMessageType(
    'RequestGetForgeState', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETFORGESTATE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetForgeState)
    ),
)
_sym_db.RegisterMessage(RequestGetForgeState)

ResponseGetForgeState = _reflection.GeneratedProtocolMessageType(
    'ResponseGetForgeState', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETFORGESTATE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetForgeState)
    ),
)
_sym_db.RegisterMessage(ResponseGetForgeState)

RequestStoreFile = _reflection.GeneratedProtocolMessageType(
    'RequestStoreFile', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTSTOREFILE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestStoreFile)
    ),
)
_sym_db.RegisterMessage(RequestStoreFile)

ResponseStoreFile = _reflection.GeneratedProtocolMessageType(
    'ResponseStoreFile', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSESTOREFILE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseStoreFile)
    ),
)
_sym_db.RegisterMessage(ResponseStoreFile)

RequestLoadFile = _reflection.GeneratedProtocolMessageType(
    'RequestLoadFile', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTLOADFILE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestLoadFile)
    ),
)
_sym_db.RegisterMessage(RequestLoadFile)

ResponseLoadFile = _reflection.GeneratedProtocolMessageType(
    'ResponseLoadFile', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSELOADFILE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseLoadFile)
    ),
)
_sym_db.RegisterMessage(ResponseLoadFile)

RequestPinFile = _reflection.GeneratedProtocolMessageType(
    'RequestPinFile', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTPINFILE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestPinFile)
    ),
)
_sym_db.RegisterMessage(RequestPinFile)

ResponsePinFile = _reflection.GeneratedProtocolMessageType(
    'ResponsePinFile', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEPINFILE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponsePinFile)
    ),
)
_sym_db.RegisterMessage(ResponsePinFile)

RequestGetChainInfo = _reflection.GeneratedProtocolMessageType(
    'RequestGetChainInfo', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETCHAININFO,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetChainInfo)
    ),
)
_sym_db.RegisterMessage(RequestGetChainInfo)

ResponseGetChainInfo = _reflection.GeneratedProtocolMessageType(
    'ResponseGetChainInfo', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETCHAININFO,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetChainInfo)
    ),
)
_sym_db.RegisterMessage(ResponseGetChainInfo)

RequestSearch = _reflection.GeneratedProtocolMessageType(
    'RequestSearch', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTSEARCH,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestSearch)
    ),
)
_sym_db.RegisterMessage(RequestSearch)

ResponseSearch = _reflection.GeneratedProtocolMessageType(
    'ResponseSearch', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSESEARCH,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseSearch)
    ),
)
_sym_db.RegisterMessage(ResponseSearch)

RequestGetUnconfirmedTxs = _reflection.GeneratedProtocolMessageType(
    'RequestGetUnconfirmedTxs', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETUNCONFIRMEDTXS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetUnconfirmedTxs)
    ),
)
_sym_db.RegisterMessage(RequestGetUnconfirmedTxs)

ResponseGetUnconfirmedTxs = _reflection.GeneratedProtocolMessageType(
    'ResponseGetUnconfirmedTxs', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETUNCONFIRMEDTXS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetUnconfirmedTxs)
    ),
)
_sym_db.RegisterMessage(ResponseGetUnconfirmedTxs)

RequestGetNetInfo = _reflection.GeneratedProtocolMessageType(
    'RequestGetNetInfo', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETNETINFO,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetNetInfo)
    ),
)
_sym_db.RegisterMessage(RequestGetNetInfo)

ResponseGetNetInfo = _reflection.GeneratedProtocolMessageType(
    'ResponseGetNetInfo', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETNETINFO,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetNetInfo)
    ),
)
_sym_db.RegisterMessage(ResponseGetNetInfo)

RequestGetValidatorsInfo = _reflection.GeneratedProtocolMessageType(
    'RequestGetValidatorsInfo', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETVALIDATORSINFO,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetValidatorsInfo)
    ),
)
_sym_db.RegisterMessage(RequestGetValidatorsInfo)

ResponseGetValidatorsInfo = _reflection.GeneratedProtocolMessageType(
    'ResponseGetValidatorsInfo', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETVALIDATORSINFO,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetValidatorsInfo)
    ),
)
_sym_db.RegisterMessage(ResponseGetValidatorsInfo)

RequestSubscribe = _reflection.GeneratedProtocolMessageType(
    'RequestSubscribe', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTSUBSCRIBE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestSubscribe)
    ),
)
_sym_db.RegisterMessage(RequestSubscribe)

ResponseSubscribe = _reflection.GeneratedProtocolMessageType(
    'ResponseSubscribe', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSESUBSCRIBE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseSubscribe)
    ),
)
_sym_db.RegisterMessage(ResponseSubscribe)

RequestUnsubscribe = _reflection.GeneratedProtocolMessageType(
    'RequestUnsubscribe', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTUNSUBSCRIBE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestUnsubscribe)
    ),
)
_sym_db.RegisterMessage(RequestUnsubscribe)

ResponseUnsubscribe = _reflection.GeneratedProtocolMessageType(
    'ResponseUnsubscribe', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEUNSUBSCRIBE,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseUnsubscribe)
    ),
)
_sym_db.RegisterMessage(ResponseUnsubscribe)

RequestGetConfig = _reflection.GeneratedProtocolMessageType(
    'RequestGetConfig', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETCONFIG,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetConfig)
    ),
)
_sym_db.RegisterMessage(RequestGetConfig)

ResponseGetConfig = _reflection.GeneratedProtocolMessageType(
    'ResponseGetConfig', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETCONFIG,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetConfig)
    ),
)
_sym_db.RegisterMessage(ResponseGetConfig)

ByDay = _reflection.GeneratedProtocolMessageType(
    'ByDay', (_message.Message,), dict(
        DESCRIPTOR=_BYDAY,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ByDay)
    ),
)
_sym_db.RegisterMessage(ByDay)

ByHour = _reflection.GeneratedProtocolMessageType(
    'ByHour', (_message.Message,), dict(
        DESCRIPTOR=_BYHOUR,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ByHour)
    ),
)
_sym_db.RegisterMessage(ByHour)

RequestGetForgeStatistics = _reflection.GeneratedProtocolMessageType(
    'RequestGetForgeStatistics', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETFORGESTATISTICS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetForgeStatistics)
    ),
)
_sym_db.RegisterMessage(RequestGetForgeStatistics)

ResponseGetForgeStatistics = _reflection.GeneratedProtocolMessageType(
    'ResponseGetForgeStatistics', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETFORGESTATISTICS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetForgeStatistics)
    ),
)
_sym_db.RegisterMessage(ResponseGetForgeStatistics)

RequestListTransactions = _reflection.GeneratedProtocolMessageType(
    'RequestListTransactions', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTLISTTRANSACTIONS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestListTransactions)
    ),
)
_sym_db.RegisterMessage(RequestListTransactions)

ResponseListTransactions = _reflection.GeneratedProtocolMessageType(
    'ResponseListTransactions', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSELISTTRANSACTIONS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseListTransactions)
    ),
)
_sym_db.RegisterMessage(ResponseListTransactions)

RequestGetAssetAddress = _reflection.GeneratedProtocolMessageType(
    'RequestGetAssetAddress', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETASSETADDRESS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetAssetAddress)
    ),
)
_sym_db.RegisterMessage(RequestGetAssetAddress)

ResponseGetAssetAddress = _reflection.GeneratedProtocolMessageType(
    'ResponseGetAssetAddress', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETASSETADDRESS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetAssetAddress)
    ),
)
_sym_db.RegisterMessage(ResponseGetAssetAddress)

RequestSignData = _reflection.GeneratedProtocolMessageType(
    'RequestSignData', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTSIGNDATA,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestSignData)
    ),
)
_sym_db.RegisterMessage(RequestSignData)

ResponseSignData = _reflection.GeneratedProtocolMessageType(
    'ResponseSignData', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSESIGNDATA,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseSignData)
    ),
)
_sym_db.RegisterMessage(ResponseSignData)

RequestGetAssets = _reflection.GeneratedProtocolMessageType(
    'RequestGetAssets', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETASSETS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetAssets)
    ),
)
_sym_db.RegisterMessage(RequestGetAssets)

ResponseGetAssets = _reflection.GeneratedProtocolMessageType(
    'ResponseGetAssets', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETASSETS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetAssets)
    ),
)
_sym_db.RegisterMessage(ResponseGetAssets)

RequestGetStakes = _reflection.GeneratedProtocolMessageType(
    'RequestGetStakes', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETSTAKES,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetStakes)
    ),
)
_sym_db.RegisterMessage(RequestGetStakes)

ResponseGetStakes = _reflection.GeneratedProtocolMessageType(
    'ResponseGetStakes', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETSTAKES,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetStakes)
    ),
)
_sym_db.RegisterMessage(ResponseGetStakes)

RequestGetTopAccounts = _reflection.GeneratedProtocolMessageType(
    'RequestGetTopAccounts', (_message.Message,), dict(
        DESCRIPTOR=_REQUESTGETTOPACCOUNTS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.RequestGetTopAccounts)
    ),
)
_sym_db.RegisterMessage(RequestGetTopAccounts)

ResponseGetTopAccounts = _reflection.GeneratedProtocolMessageType(
    'ResponseGetTopAccounts', (_message.Message,), dict(
        DESCRIPTOR=_RESPONSEGETTOPACCOUNTS,
        __module__='rpc_pb2',
        # @@protoc_insertion_point(class_scope:forge_abi.ResponseGetTopAccounts)
    ),
)
_sym_db.RegisterMessage(ResponseGetTopAccounts)


# @@protoc_insertion_point(module_scope)
